@@ -116,6 +116,7 @@ UBX_CONFIG_DATABASE = {
     # CFG_I2COUTPROT Output protocol configuration of the I2C interface
     "CFG_I2COUTPROT_UBX": (0x10720001, L),
     "CFG_I2COUTPROT_NMEA": (0x10720002, L),
+    "CFG_I2COUTPROT_RTCM3X": (0x10720004, L),
     # CFG_INFMSG Information message configuration
     "CFG_INFMSG_UBX_I2C": (0x20920001, X1),
     "CFG_INFMSG_UBX_UART1": (0x20920002, X1),
@@ -230,6 +231,66 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_PUBX_ID_POLYT_UART1": (0x209100F7, U1),
     "CFG_MSGOUT_PUBX_ID_POLYT_UART2": (0x209100F8, U1),
     "CFG_MSGOUT_PUBX_ID_POLYT_USB": (0x209100F9, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1005_I2C": (0x209102BD, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1005_SPI": (0x209102C1, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1005_UART1": (0x209102BE, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1005_UART2": (0x209102BF, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1005_USB": (0x209102C0, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1074_I2C": (0x2091035E, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1074_SPI": (0x20910362, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1074_UART1": (0x2091035F, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1074_UART2": (0x20910360, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1074_USB": (0x20910361, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1077_I2C": (0x209102CC, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1077_SPI": (0x209102D0, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1077_UART1": (0x209102CD, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1077_UART2": (0x209102CE, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1077_USB": (0x209102CF, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1084_I2C": (0x20910363, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1084_SPI": (0x20910367, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1084_UART1": (0x20910364, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1084_UART2": (0x20910365, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1084_USB": (0x20910366, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1087_I2C": (0x209102D1, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1087_SPI": (0x209102D5, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1087_UART1": (0x209102D2, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1087_UART2": (0x209102D3, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1087_USB": (0x209102D4, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1094_I2C": (0x20910368, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1094_SPI": (0x2091036C, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1094_UART1": (0x20910369, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1094_UART2": (0x2091036A, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1094_USB": (0x2091036B, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1097_I2C": (0x20910318, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1097_SPI": (0x2091031C, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1097_UART1": (0x20910319, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1097_UART2": (0x2091031A, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1097_USB": (0x2091031B, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1124_I2C": (0x2091036D, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1124_SPI": (0x20910371, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1124_UART1": (0x2091036E, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1124_UART2": (0x2091036F, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1124_USB": (0x20910370, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1127_I2C": (0x209102D6, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1127_SPI": (0x209102DA, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1127_UART1": (0x209102D7, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1127_UART2": (0x209102D8, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1127_USB": (0x209102D9, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1230_I2C": (0x20910303, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1230_SPI": (0x20910307, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1230_UART1": (0x20910304, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1230_UART2": (0x20910305, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1230_USB": (0x20910306, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE4072_0_I2C": (0x209102FE, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE4072_0_SPI": (0x20910302, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE4072_0_UART1": (0x209102FF, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE4072_0_UART2": (0x20910300, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE4072_0_USB": (0x20910301, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE4072_1_I2C": (0x20910381, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE4072_1_SPI": (0x20910385, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE4072_1_UART1": (0x20910382, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE4072_1_UART2": (0x20910383, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE4072_1_USB": (0x20910384, U1),
     "CFG_MSGOUT_UBX_LOG_INFO_I2C": (0x20910259, U1),
     "CFG_MSGOUT_UBX_LOG_INFO_SPI": (0x2091025D, U1),
     "CFG_MSGOUT_UBX_LOG_INFO_UART1": (0x2091025A, U1),
@@ -593,6 +654,25 @@ UBX_CONFIG_DATABASE = {
     # CFG_SPIOUTPROT Output protocol configuration of the SPI interface
     "CFG_SPIOUTPROT_UBX": (0x107A0001, L),
     "CFG_SPIOUTPROT_NMEA": (0x107A0002, L),
+    "CFG_SPIOUTPROT_RTCM3X": (0x107A0004, L),
+    # CFG_TMODE Time mode configuration
+    "CFG_TMODE_MODE": (0x20030001, E1),
+    "CFG_TMODE_POS_TYPE": (0x20030002, E1),
+    "CFG_TMODE_ECEF_X": (0x20030003, I4),
+    "CFG_TMODE_ECEF_Y": (0x20030004, I4),
+    "CFG_TMODE_ECEF_Z": (0x20030005, I4),
+    "CFG_TMODE_ECEF_X_HP": (0x20030006, I1),
+    "CFG_TMODE_ECEF_Y_HP": (0x20030007, I1),
+    "CFG_TMODE_ECEF_Z_HP": (0x20030008, I1),
+    "CFG_TMODE_LAT": (0x20030009, I4),
+    "CFG_TMODE_LON": (0x2003000A, I4),
+    "CFG_TMODE_HEIGHT": (0x2003000B, I4),
+    "CFG_TMODE_LAT_HP": (0x2003000C, I1),
+    "CFG_TMODE_LON_HP": (0x2003000D, I1),
+    "CFG_TMODE_HEIGHT_HP": (0x2003000E, I1),
+    "CFG_TMODE_FIXED_POS_ACC": (0x2003000F, U4),
+    "CFG_TMODE_SVIN_MIN_DUR": (0x20030010, U4),
+    "CFG_TMODE_SVIN_ACC_LIMIT": (0x20030011, U4),
     # CFG_TP Timepulse configuration
     "CFG_TP_PULSE_DEF": (0x20050023, E1),
     "CFG_TP_PULSE_LENGTH_DEF": (0x20050030, E1),
@@ -646,6 +726,7 @@ UBX_CONFIG_DATABASE = {
     # CFG_UART1OUTPROT Output protocol configuration of the UART1 interface
     "CFG_UART1OUTPROT_UBX": (0x10740001, L),
     "CFG_UART1OUTPROT_NMEA": (0x10740002, L),
+    "CFG_UART1OUTPROT_RTCM3X": (0x10740004, L),
     # CFG_UART2 Configuration of the UART2 interface
     "CFG_UART2_BAUDRATE": (0x40530001, U4),
     "CFG_UART2_STOPBITS": (0x20530002, E1),
@@ -660,6 +741,7 @@ UBX_CONFIG_DATABASE = {
     # CFG_UART2OUTPROT Output protocol configuration of the UART2 interface
     "CFG_UART2OUTPROT_UBX": (0x10760001, L),
     "CFG_UART2OUTPROT_NMEA": (0x10760002, L),
+    "CFG_UART2OUTPROT_RTCM3X": (0x10760004, L),
     # CFG_USB Configuration of the USB interface
     "CFG_USB_ENABLED": (0x10650001, L),
     "CFG_USB_SELFPOW": (0x10650002, L),
@@ -685,4 +767,5 @@ UBX_CONFIG_DATABASE = {
     # CFG_USBOUTPROT Output protocol configuration of the USB interface
     "CFG_USBOUTPROT_UBX": (0x10780001, L),
     "CFG_USBOUTPROT_NMEA": (0x10780002, L),
+    "CFG_USBOUTPROT_RTCM3X": (0x10780004, L),
 }
